﻿using System;
using MccDaq; // add reference to project for MccDaq

namespace TinSCanExample
{
    class Program
    {
        public const int BLOCKSIZE = 50;
        public const int CHANCOUNT = 4;
        public const int FIRSTCHANNEL = 0;
        public const int LASTCHANNEL = 3;
        public const int FREQ = 2;
        public const int BUFFERSIZE = BLOCKSIZE * CHANCOUNT;
        public const string DEVICE = "TC";


        static void Main(string[] args)
        {

            MccDaq.ErrorInfo RetVal;

            int BoardNum = 0;

            //locate the USB-TC
            BoardNum = GetBoardNum(DEVICE);

            if (BoardNum == -1)
                Console.WriteLine("No USB-{0} detected!", DEVICE);
            else
            {
                MccBoard daq = new MccDaq.MccBoard(BoardNum);

                float[] TempData = new float[CHANCOUNT];
                for (int i = 0; i < BLOCKSIZE; i++)
                {
                    RetVal = daq.TInScan(FIRSTCHANNEL, LASTCHANNEL, TempScale.Fahrenheit, TempData, ThermocoupleOptions.Filter);

                    IsError(RetVal);

                    DisplayData(TempData);
                }
                WaitForKey();
            }

        }
        /************************************************************************/
        public static int GetBoardNum(string dev)
        {
            for (int BoardNum = 0; BoardNum < 99; BoardNum++)
            {
                MccDaq.MccBoard daq = new MccDaq.MccBoard(BoardNum);
                if (daq.BoardName.Contains(dev))
                {
                    Console.WriteLine("USB-{0} board number = {1}", dev, BoardNum.ToString());
                    daq.FlashLED();
                    return BoardNum;
                }
            }
            return -1;
        }
        /************************************************************************/

        public static void WaitForKey()
        {
            Console.WriteLine("\nPress <SpaceBar> to continue...");
            System.ConsoleKeyInfo cki;
            do
            {
                cki = Console.ReadKey();
            } while (cki.Key != ConsoleKey.Spacebar);
        }

        /************************************************************************/

        public static int IsError(ErrorInfo e)
        {
            if (e.Value != 0)
            {
                Console.WriteLine(e.Message);
                WaitForKey();
                return 1;
            }
            return 0;
        }

        /************************************************************************/

        public static void DisplayData(float[] datArray)
        {
            for (int c = 0; c < CHANCOUNT; c++)
                Console.Write("{0}F\t", datArray[c].ToString("0.00").PadLeft(10));
            Console.Write("\r\n");
        }

        /************************************************************************/

    }
}


